package org.jeecg.modules.api.travelController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.apiBean.PageBean;
import org.jeecg.modules.apiService.IndexApiService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;


@Api(tags="小程序-首页相关接口")
@RestController
@RequestMapping("/api/info")
@Slf4j
public class IndexApiController {

    @Resource
    private IndexApiService indexApiService;

    //获取小程序任一文章或服务

    //获取banner图列表
    @ApiOperation(value="小程序-获取banner图列表", notes="1-轮播图_首页")
    @GetMapping()
    @RequestMapping(value = "/queryBannerList", method = {RequestMethod.GET})
    public Result<?> queryBannerList(String bannerCategoryType){
        return indexApiService.queryBannerList(bannerCategoryType);
    };

    //获取视频列表
    @ApiOperation(value="小程序-获取视频列表", notes="小程序-获取视频列表")
    @RequestMapping(value = "/queryVideoList", method = {RequestMethod.GET})
    public Result<?> queryVideoList(PageBean pageBean){
        return indexApiService.queryVideoList(pageBean);
    }

//    //获取文章列表-申遗历程/非遗体验
//    @ApiOperation(value="小程序-获取文章列表", notes="小程序-获取文章列表")
//    @RequestMapping(value = "/queryArticleList", method = {RequestMethod.GET})
//    public Result<?> queryArticleList(PageBean pageBean){
//        return indexApiService.queryArticleList(pageBean);
//    }

    //根据分类获取文章列表
    @ApiOperation(value="小程序-根据分类获取文章列表", notes="1-申遗历程 2-申遗缘由 3-遗产价值")
    @RequestMapping(value = "/queryArticleListByType", method = {RequestMethod.GET})
    public Result<?> queryArticleListByType(String articleType, PageBean pageBean){
        return indexApiService.queryArticleListByType(articleType, pageBean);
    }

    //根据id获取文章详情
    @ApiOperation(value="小程序-根据id获取文章详情", notes="小程序-根据id获取文章详情")
    @RequestMapping(value = "/queryArticleById", method = {RequestMethod.GET})
    public Result<?> queryArticleById(String articleId){
        return indexApiService.queryArticleById(articleId);
    }

    //获取景区列表
    @ApiOperation(value="小程序-获取景区列表", notes="小程序-获取景区列表")
    @RequestMapping(value = "/queryAreaList", method = {RequestMethod.GET})
    public Result<?> queryAreaList(PageBean pageBean){
        return indexApiService.queryAreaList(pageBean);
    }

    //获取景区列表
    @ApiOperation(value="小程序-根据id获取景区详情", notes="小程序-根据id获取景区详情")
    @RequestMapping(value = "/queryAreaListById", method = {RequestMethod.GET})
    public Result<?> queryAreaListById(String areaId){
        return indexApiService.queryAreaListById(areaId);
    }

    //根据景区id获取该景区下的地点列表-景点/厕所/美食店铺/民宿
    @ApiOperation(value="小程序-根据景区id获取该景区下的地点列表", notes="areaId: 1-瓷都镇区 2-湖田片区 3-高岭片区 4-瑶里片区 5-蛟潭片区; categoryTyep: 1-景点 2-美食店铺 3-民宿 4-厕所")
    @RequestMapping(value = "/querySpotList", method = {RequestMethod.GET})
    public Result<?> querySpotList(String areaId, String categoryId, PageBean pageBean){
        return indexApiService.querySpotList(areaId, categoryId, pageBean);
    }

    //根据角色类型获取角色信息列表-讲解员/达人/摄影师
    @ApiOperation(value="小程序-根据角色类型获取角色信息列表", notes="roleId: 1-讲解员，2-达人，3-摄影师")
    @RequestMapping(value = "/queryRoleInfoList", method = {RequestMethod.GET})
    public Result<?> queryRoleInfoList(String roleId, String level, String spot, PageBean pageBean){
        return indexApiService.queryRoleInfoList(roleId, level, spot, pageBean);
    }

    //根据角色id获取角色信息详情
    @ApiOperation(value="小程序-根据角色Id获取角色信息详情", notes="小程序-根据角色Id获取角色信息详情")
    @RequestMapping(value = "/queryRoleInfoById", method = {RequestMethod.GET})
    public Result<?> queryRoleInfoById(String roleInfoId){
        return indexApiService.queryRoleInfoById(roleInfoId);
    }

    //根据角色id获取视频列表
    @ApiOperation(value="小程序-根据角色id获取视频列表", notes="小程序-根据角色id获取视频列表")
    @RequestMapping(value = "/queryVedioBySpot", method = {RequestMethod.GET})
    public Result<?> queryVedioById(String roleInfoId, PageBean pageBean){
        return indexApiService.queryVedioById(roleInfoId, pageBean);
    }

    //遗产路径-待补充

    //我要研学-待补充

    //文创好物-待补充

    //瓷都美食-链接美团

    //精品民宿-链接高德地图

    //无忧租车-链接滴滴打车

    //添加建议
    @ApiOperation(value="小程序-添加建议", notes="小程序-添加建议")
    @RequestMapping(value = "/addAdvice", method = {RequestMethod.POST})
    public Result<?> addAdvice(){
        return indexApiService.addAdvice();
    }

    /*************************我的***********************************/
    //添加志愿者
    @ApiOperation(value="小程序-添加志愿者", notes="小程序-添加志愿者")
    @RequestMapping(value = "/addVolunteer", method = {RequestMethod.POST})
    public Result<?> addVolunteer(){
        return indexApiService.addVolunteer();
    }


}
