package org.jeecg.modules.apiService.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.apiBean.PageBean;
import org.jeecg.modules.apiService.IndexApiService;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.jeecg.modules.travelArea.entity.TravelArea;
import org.jeecg.modules.travelArea.service.ITravelAreaService;
import org.jeecg.modules.travelArticle.entity.TravelArticle;
import org.jeecg.modules.travelArticle.service.ITravelArticleService;
import org.jeecg.modules.travelCategory.service.ITravelCategoryService;
import org.jeecg.modules.travelCertification.service.ITravelCertificationService;
import org.jeecg.modules.travelImage.entity.TravelImage;
import org.jeecg.modules.travelImage.service.ITravelImageService;
import org.jeecg.modules.travelOrder.service.ITravelOrderService;
import org.jeecg.modules.travelRole.service.ITravelRoleService;
import org.jeecg.modules.travelRoleInfo.entity.TravelRoleInfo;
import org.jeecg.modules.travelRoleInfo.service.ITravelRoleInfoService;
import org.jeecg.modules.travelSpot.entity.TravelSpot;
import org.jeecg.modules.travelSpot.service.ITravelSpotService;
import org.jeecg.modules.travelVideo.entity.TravelVideo;
import org.jeecg.modules.travelVideo.service.ITravelVideoService;
import org.jeecg.modules.travelVolunteer.service.ITravelVolunteerService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
public class IndexApiServiceImpl implements IndexApiService {

    //获取小程序任一文章或服务

    //用户表
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    //角色表
    @Resource
    private ITravelRoleService travelRoleService;
    //角色信息表
    @Resource
    private ITravelRoleInfoService travelRoleInfoService;
    //景区表
    @Resource
    private ITravelAreaService travelAreaService;
    //景点表
    @Resource
    private ITravelSpotService travelSpotService;
    //分类表
    @Resource
    private ITravelCategoryService travelCategoryService;
    //图片表
    @Resource
    private ITravelImageService travelImageService;
    //文章表
    @Resource
    private ITravelArticleService travelArticleService;
    //视频表
    @Resource
    private ITravelVideoService travelVideoService;
    //证件表
    @Resource
    private ITravelCertificationService travelCertificationService;
    //订单表
    @Resource
    private ITravelOrderService travelOrderService;
    //志愿者表
    @Resource
    private ITravelVolunteerService travelVolunteerService;

    //获取轮播图列表
    @Override
    public Result<?> queryBannerList(String bannerCategoryId) {

        //1-轮播图_首页
        switch (bannerCategoryId){
            case "1": bannerCategoryId = "1836222983394902017";
                break;
        }

        List<TravelImage> list = travelImageService
                .lambdaQuery()
                .eq(TravelImage::getCategoryId, bannerCategoryId)
                .orderByAsc(TravelImage::getOrderId)
                .list();

        return Result.OK("轮播图列表", list);
    }

    //获取视频列表带分页
    @Override
    public Result<?> queryVideoList(PageBean pageBean) {
        Page<TravelVideo> page = new Page<TravelVideo>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelVideo> pageList = travelVideoService
                .lambdaQuery()
                .orderByDesc(TravelVideo::getCreateTime)
                .page(page);

        return Result.OK("视频列表", pageList);
    }

    //获取文章列表带分页
    @Override
    public Result<?> queryArticleList(PageBean pageBean) {
        Page<TravelArticle> page = new Page<TravelArticle>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelArticle> pageList = travelArticleService
                .lambdaQuery()
                .orderByDesc(TravelArticle::getCreateTime)
                .page(page);

        return Result.OK("文章列表", pageList);
    }

    //根据文章类型获取文章列表带分页
    @Override
    public Result<?> queryArticleListByType(String articleType, PageBean pageBean) {

        //1-申遗历程 2-申遗缘由 3-遗产价值
        if(null != articleType){
            switch (articleType){
                case "1": articleType = "1836253741344075777";
                    break;
                case "2": articleType = "1836253813855203330";
                    break;
                case "3": articleType = "1836253884822827009";
                    break;
                default: articleType = null;
            }
        }

        Page<TravelArticle> page = new Page<TravelArticle>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelArticle> pageList =null;

        if(null != articleType){

            pageList = travelArticleService
                    .lambdaQuery()
                    .eq(TravelArticle::getCategoryId, articleType)
                    .orderByDesc(TravelArticle::getCreateTime)
                    .page(page);
        }else {
            pageList = travelArticleService
                    .lambdaQuery()
                    .orderByDesc(TravelArticle::getCreateTime)
                    .page(page);
        }

        return Result.OK("文章列表", pageList);
    }

    //根据文章id获取文章详情
    @Override
    public Result<?> queryArticleById(String articleId) {
        TravelArticle one = travelArticleService
                .lambdaQuery()
                .eq(TravelArticle::getId, articleId)
                .one();

        return Result.OK("文章详情", one);
    }

    //获取景区列表带分页
    @Override
    public Result<?> queryAreaList(PageBean pageBean) {

        Page<TravelArea> page = new Page<TravelArea>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelArea> pageList = travelAreaService
                .lambdaQuery()
                .page(page);

        return Result.OK("景区列表", pageList);
    }

    //根据id获取景区详情
    @Override
    public Result<?> queryAreaListById(String areaId) {
        TravelArea one = travelAreaService
                .lambdaQuery()
                .eq(TravelArea::getId, areaId)
                .one();

        return Result.OK("景区详情", one);
    }

    //根据景区id获取该景区下的地点列表-景点/厕所/美食店铺/民宿带分页
    @Override
    public Result<?> querySpotList(String areaId, String categoryId, PageBean pageBean) {

        //1-瓷都镇区 2-湖田片区 3-高岭片区 4-瑶里片区 5-蛟潭片区
        if(null != areaId){
            switch (areaId){
                case "1": areaId = "1835255148875296770";
                    break;
                case "2": areaId = "1835296270515376130";
                    break;
                case "3": areaId = "1835296379189792769";
                    break;
                case "4": areaId = "1835296552271941634";
                    break;
                case "5": areaId = "1835296680814776322";
                    break;
                default: areaId = null;
            }
        }

        //1-景点 2-美食店铺 3-民宿 4-厕所
        if(null != categoryId){
            switch (categoryId){
                case "1": categoryId = "1835297869300174849";
                    break;
                case "2": categoryId = "1835298116864774146";
                    break;
                case "3": categoryId = "1835298190902628353";
                    break;
                case "4": categoryId = "1835297932831297538";
                    break;
                default: categoryId = null;
            }
        }

        Page<TravelSpot> page = new Page<TravelSpot>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelSpot> pageList = null;
        if(null != areaId && null != categoryId){
            pageList = travelSpotService
                    .lambdaQuery()
                    .eq(TravelSpot::getAreaId, areaId)
                    .eq(TravelSpot::getCategoryId, categoryId)
                    .page(page);
        }else if(null != areaId){
            pageList = travelSpotService
                    .lambdaQuery()
                    .eq(TravelSpot::getAreaId, areaId)
                    .page(page);
        }else if(null != categoryId){
            pageList = travelSpotService
                    .lambdaQuery()
                    .eq(TravelSpot::getCategoryId, categoryId)
                    .page(page);
        }else {
            pageList = travelSpotService
                    .lambdaQuery()
                    .page(page);
        }

        return Result.OK("景点列表", pageList);
    }

    //根据角色类型获取角色信息列表
    @Override
    public Result<?> queryRoleInfoList(String roleId, String level, String spot, PageBean pageBean) {

        //roleId: 1-讲解员，2-达人，3-摄影师
        if(null != roleId){
            switch (roleId){
                case "1":
                    roleId = "1835298310465458178";
                    break;
                case "2":
                    roleId = "1835298364374847490";
                    break;
                case "3":
                    roleId = "1835298430967812098";
                    break;
                default: roleId = null;
            }
        }

        Page<TravelRoleInfo> page = new Page<TravelRoleInfo>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelRoleInfo> pageList = null;

        if(null != roleId &&null != level && null != spot){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleId, roleId)
                    .eq(TravelRoleInfo::getRoleLevel, level)
                    .like(TravelRoleInfo::getSkill, spot)
                    .page(page);
        }else if(null != roleId && null != level){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleId, roleId)
                    .eq(TravelRoleInfo::getRoleLevel, level)
                    .page(page);
        }else if(null != roleId && null != spot){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleId, roleId)
                    .like(TravelRoleInfo::getSkill, spot)
                    .page(page);
        }else if(null != level && null != spot){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleLevel, level)
                    .like(TravelRoleInfo::getSkill, spot)
                    .page(page);
        }else if(null != roleId){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleId, roleId)
                    .page(page);
        }else if(null != level){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .eq(TravelRoleInfo::getRoleLevel, level)
                    .page(page);
        }else if(null != spot){
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .like(TravelRoleInfo::getSkill, spot)
                    .page(page);
        }else{
            pageList = travelRoleInfoService
                    .lambdaQuery()
                    .page(page);
        }

        return Result.OK("角色列表", pageList);
    }

    //根据角色id获取角色详情
    @Override
    public Result<?> queryRoleInfoById(String roleInfoId) {
        TravelRoleInfo one = travelRoleInfoService
                .lambdaQuery()
                .eq(TravelRoleInfo::getId, roleInfoId)
                .one();

        return Result.OK("角色详情", one);
    }

    //根据视频创建者获取视频列表
    @Override
    public Result<?> queryVedioById(String roleInfoId, PageBean pageBean) {

        Page<TravelVideo> page = new Page<TravelVideo>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<TravelVideo> pageList = travelVideoService
                .lambdaQuery()
                .eq(TravelVideo::getCreateBy, roleInfoId)
                .orderByDesc(TravelVideo::getCreateTime)
                .page(page);

        return Result.OK("视频列表", pageList);
    }

    //添加建议
    @Override
    public Result<?> addAdvice() {
        return null;
    }

    //添加志愿者
    @Override
    public Result<?> addVolunteer() {
        return null;
    }
}
